@@ -21,7 +21,6 @@ from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 
 from gajim.common import app
-from gajim.common import helpers
 from gajim.common import modules
 from gajim.common import passwords
 from gajim.common.client_modules import ClientModules
@@ -38,7 +37,6 @@ from gajim.common.events import StanzaReceived
 from gajim.common.events import StanzaSent
 from gajim.common.helpers import get_account_proxy
 from gajim.common.helpers import get_custom_host
-from gajim.common.helpers import get_idle_status_message
 from gajim.common.helpers import get_resource
 from gajim.common.helpers import Observable
 from gajim.common.helpers import warn_about_plain_connection
@@ -47,8 +45,10 @@ from gajim.common.idle import IdleMonitorManager
 from gajim.common.idle import Monitor
 from gajim.common.structs import OutgoingMessage
 from gajim.common.util.http import create_http_session
+from gajim.common.util.status import get_idle_status_message
+from gajim.common.util.text import to_one_line
 
-from gajim.gtk.util import open_window
+from gajim.gtk.util.window import open_window
 
 log = logging.getLogger('gajim.client')
 
@@ -56,6 +56,15 @@ log = logging.getLogger('gajim.client')
 IgnoredTlsErrorsT = set[Gio.TlsCertificateFlags] | None
 
 
+def call_counter(func: Any):
+    def helper(self, restart: bool = False) -> Any:
+        if restart:
+            self._connect_machine_calls = 0
+        self._connect_machine_calls += 1
+        return func(self)
+    return helper
+
+
 class Client(Observable, ClientModules):
     def __init__(self, account: str) -> None:
         Observable.__init__(self, log)
@@ -152,6 +161,11 @@ class Client(Observable, ClientModules):
 
     def _create_client(self) -> None:
         log.info('Create new nbxmpp client')
+
+        if self._client is not None:
+            self._client.destroy()
+            self._destroy_client = False
+
         self._client = NBXMPPClient(log_context=self._account)
         self.connection = self._client
         self._client.set_domain(self._address.domain)
@@ -197,18 +211,35 @@ class Client(Observable, ClientModules):
         self._set_state(ClientState.AVAILABLE)
         app.ged.raise_event(AccountConnected(account=self._account))
 
+        if not app.settings.get_account_setting(self._account, 'autojoin_sync'):
+            self.join_mucs()
+
     def disconnect(self,
                    gracefully: bool,
                    reconnect: bool,
                    destroy_client: bool = False) -> None:
 
+        self._reconnect = reconnect
+        self._destroy_client = destroy_client
+
+        if self._state.is_reconnect_scheduled:
+            self._abort_reconnect()
+            if reconnect:
+                self.connect()
+            return
+
+        if self._state.is_disconnected:
+            if destroy_client:
+                self._create_client()
+            if reconnect:
+                self.connect()
+            return
+
         if self._state.is_disconnecting:
             log.warning('Disconnect already in progress')
             return
 
         self._set_state(ClientState.DISCONNECTING)
-        self._reconnect = reconnect
-        self._destroy_client = destroy_client
 
         log.info('Starting to disconnect %s', self._account)
         self._client.disconnect(immediate=not gracefully)
@@ -283,13 +314,9 @@ class Client(Observable, ClientModules):
     def _after_disconnect(self) -> None:
         self._disable_reconnect_timer()
 
-        app.proxy65_manager.disconnect(self._client)
         self.get_module('Bytestream').remove_all_transfers()
 
         if self._destroy_client:
-            self._client.destroy()
-            self._client = None
-            self._destroy_client = False
             self._create_client()
 
         app.ged.raise_event(AccountDisconnected(account=self._account))
@@ -364,7 +391,7 @@ class Client(Observable, ClientModules):
             app.settings.set_account_setting(
                 self._account,
                 'last_status_msg',
-                helpers.to_one_line(message))
+                to_one_line(message))
 
         if self._state.is_disconnecting:
             log.warning("Can't change status while disconnect is in progress")
@@ -421,7 +448,7 @@ class Client(Observable, ClientModules):
         if include_muc:
             self.get_module('MUC').update_presence()
 
-    @helpers.call_counter
+    @call_counter
     def connect_machine(self) -> None:
         log.info('Connect machine state: %s', self._connect_machine_calls)
         if self._connect_machine_calls == 1:
@@ -568,9 +595,6 @@ class Client(Observable, ClientModules):
         self._disable_reconnect_timer()
 
         if self._destroy_client:
-            self._client.destroy()
-            self._client = None
-            self._destroy_client = False
             self._create_client()
 
         self.notify('state-changed', SimpleClientState.DISCONNECTED)
@@ -592,8 +616,8 @@ class Client(Observable, ClientModules):
         if not app.settings.get(f'auto{state}'):
             return
 
-        if (state in ('away', 'xa') and self._status == 'online' or
-                state == 'xa' and self._idle_status == 'away'):
+        if ((state in ('away', 'xa') and self._status == 'online') or
+                (state == 'xa' and self._idle_status == 'away')):
 
             self._idle_status = state
             self._idle_status_message = get_idle_status_message(
@@ -630,6 +654,17 @@ class Client(Observable, ClientModules):
         active = application.get_property('screensaver-active')
         Monitor.set_extended_away(active)
 
+    def join_mucs(self) -> None:
+        '''Only used when autojoin_sync is False'''
+        self._log.info('Joining all MUCs in all workspaces')
+        for workspace_id in app.settings.get_workspaces():
+            for chat in app.settings.get_workspace_setting(
+                    workspace_id, 'chats'):
+                if chat['account'] != self._account:
+                    continue
+                if chat['type'] == 'groupchat':
+                    self.get_module('MUC').join(chat['jid'])
+
     def cleanup(self) -> None:
         self.disconnect_signals()
         self._destroyed = True
