@@ -5,6 +5,7 @@
 from __future__ import annotations
 
 from typing import Any
+from typing import cast
 from typing import Literal
 from typing import overload
 
@@ -12,10 +13,13 @@ import logging
 from functools import partial
 from unittest.mock import Mock
 
+from nbxmpp.dispatcher import NBXMPPModuleNameT
+from nbxmpp.dispatcher import NBXMPPModuleT
 from nbxmpp.modules.activity import Activity
 from nbxmpp.modules.adhoc import AdHoc
 from nbxmpp.modules.annotations import Annotations
 from nbxmpp.modules.attention import Attention
+from nbxmpp.modules.base import BaseModule as NBXMPPBaseModule
 from nbxmpp.modules.blocking import Blocking
 from nbxmpp.modules.bookmarks.native_bookmarks import NativeBookmarks
 from nbxmpp.modules.bookmarks.pep_bookmarks import PEPBookmarks
@@ -25,6 +29,7 @@ from nbxmpp.modules.chat_markers import ChatMarkers
 from nbxmpp.modules.chatstates import Chatstates
 from nbxmpp.modules.correction import Correction
 from nbxmpp.modules.delay import Delay
+from nbxmpp.modules.delimiter import Delimiter
 from nbxmpp.modules.discovery import Discovery
 from nbxmpp.modules.eme import EME
 from nbxmpp.modules.entity_caps import EntityCaps
@@ -37,8 +42,10 @@ from nbxmpp.modules.iq import BaseIq
 from nbxmpp.modules.last_activity import LastActivity
 from nbxmpp.modules.location import Location
 from nbxmpp.modules.mam import MAM
+from nbxmpp.modules.mds import MDS
 from nbxmpp.modules.message import BaseMessage
 from nbxmpp.modules.mood import Mood
+from nbxmpp.modules.muc.hats import Hats
 from nbxmpp.modules.muc.moderation import Moderation
 from nbxmpp.modules.muc.muc import MUC
 from nbxmpp.modules.muclumbus import Muclumbus
@@ -54,6 +61,7 @@ from nbxmpp.modules.reactions import Reactions
 from nbxmpp.modules.receipts import Receipts
 from nbxmpp.modules.register.register import Register
 from nbxmpp.modules.replies import Replies
+from nbxmpp.modules.retraction import Retraction
 from nbxmpp.modules.roster import Roster
 from nbxmpp.modules.security_labels import SecurityLabels
 from nbxmpp.modules.software_version import SoftwareVersion
@@ -74,7 +82,7 @@ from gajim.common.modules.util import LogAdapter
 
 class BaseModule(EventHelper):
 
-    _nbxmpp_extends = ''
+    _nbxmpp_extends: NBXMPPModuleNameT = ''  # type: ignore
     _nbxmpp_methods: list[str] = []
 
     def __init__(self,
@@ -115,17 +123,20 @@ class BaseModule(EventHelper):
             self._log.warning('Account not connected, can’t use %s', key)
             return None
 
-        module = self._con.connection.get_module(self._nbxmpp_extends)
+        module = cast(
+            NBXMPPBaseModule,
+            self._con.connection.get_module(self._nbxmpp_extends)
+        )
 
         callback = self._nbxmpp_callbacks.get(key)
         if callback is None:
             return getattr(module, key)
         return partial(getattr(module, key), callback=callback)
 
-    def _register_callback(self, method, callback) -> None:
+    def _register_callback(self, method: str, callback: types.AnyCallableT) -> None:
         self._nbxmpp_callbacks[method] = callback
 
-    def _register_pubsub_handler(self, callback: types.AnyCallableT):
+    def _register_pubsub_handler(self, callback: types.AnyCallableT) -> None:
         handler = StanzaHandler(name='message',
                                 callback=callback,
                                 ns=Namespace.PUBSUB_EVENT,
@@ -179,6 +190,8 @@ class BaseModule(EventHelper):
     @overload
     def _nbxmpp(self, name: Literal['Delay']) -> Delay: ...
     @overload
+    def _nbxmpp(self, name: Literal['Delimiter']) -> Delimiter: ...
+    @overload
     def _nbxmpp(self, name: Literal['Discovery']) -> Discovery: ...
     @overload
     def _nbxmpp(self, name: Literal['EME']) -> EME: ...
@@ -187,6 +200,8 @@ class BaseModule(EventHelper):
     @overload
     def _nbxmpp(self, name: Literal['EntityTime']) -> EntityTime: ...
     @overload
+    def _nbxmpp(self, name: Literal['Hats']) -> Hats: ...
+    @overload
     def _nbxmpp(self, name: Literal['HTTPAuth']) -> HTTPAuth: ...
     @overload
     def _nbxmpp(self, name: Literal['HTTPUpload']) -> HTTPUpload: ...
@@ -205,6 +220,8 @@ class BaseModule(EventHelper):
     @overload
     def _nbxmpp(self, name: Literal['BaseMessage']) -> BaseMessage: ...
     @overload
+    def _nbxmpp(self, name: Literal['MDS']) -> MDS: ...
+    @overload
     def _nbxmpp(self, name: Literal['Mood']) -> Mood: ...
     @overload
     def _nbxmpp(self, name: Literal['MUC']) -> MUC: ...
@@ -237,6 +254,8 @@ class BaseModule(EventHelper):
     @overload
     def _nbxmpp(self, name: Literal['Replies']) -> Replies: ...
     @overload
+    def _nbxmpp(self, name: Literal['Retraction']) -> Retraction: ...
+    @overload
     def _nbxmpp(self, name: Literal['Roster']) -> Roster: ...
     @overload
     def _nbxmpp(self, name: Literal['SecurityLabels']) -> SecurityLabels: ...
@@ -253,11 +272,11 @@ class BaseModule(EventHelper):
     @overload
     def _nbxmpp(self, name: Literal['VCardTemp']) -> VCardTemp: ...
     @overload
-    def _nbxmpp(self) -> types.Client: ...
+    def _nbxmpp(self) -> types.NBXMPPClient: ...
 
     def _nbxmpp(self,
-                name: str | None = None
-                ) -> Mock | types.Client | BaseModule:
+                name: NBXMPPModuleNameT | None = None
+                ) -> Mock | types.NBXMPPClient | NBXMPPModuleT:
 
         if not app.account_is_connected(self._client.account):
             self._log.warning('Account not connected, can’t use nbxmpp method')
