@@ -65,10 +65,10 @@ class MAM(BaseModule):
         ]
 
         self.available = False
-        self._mam_query_ids: dict[str, str] = {}
+        self._mam_query_ids: dict[JID, str] = {}
 
         # Holds archive jids where catch up was successful
-        self._catch_up_finished: list[str] = []
+        self._catch_up_finished: list[JID] = []
 
         self._con.connect_signal('state-changed', self._on_client_state_changed)
         self._con.connect_signal('resume-failed', self._on_client_resume_failed)
@@ -102,10 +102,16 @@ class MAM(BaseModule):
         self._mam_query_ids.clear()
         self._catch_up_finished.clear()
 
-    def _remove_query_id(self, jid: JID) -> None:
+    def _remove_query_by_jid(self, jid: JID) -> None:
         self._mam_query_ids.pop(jid, None)
 
-    def is_catch_up_finished(self, jid: str) -> bool:
+    def _remove_query_by_id(self, queryid: str) -> None:
+        for jid, _queryid in list(self._mam_query_ids.items()):
+            if _queryid == queryid:
+                del self._mam_query_ids[jid]
+                return
+
+    def is_catch_up_finished(self, jid: JID) -> bool:
         return jid in self._catch_up_finished
 
     def _from_valid_archive(self,
@@ -113,6 +119,7 @@ class MAM(BaseModule):
                             properties: MessageProperties
                             ) -> bool:
         if properties.type.is_groupchat:
+            assert properties.jid is not None
             expected_archive = properties.jid
         else:
             expected_archive = self._con.get_own_jid()
@@ -122,10 +129,10 @@ class MAM(BaseModule):
 
     @staticmethod
     def _get_stanza_id(properties: MessageProperties,
-                       archive_jid: str
+                       archive_jid: JID
                        ) -> StanzaIDData | None:
         for stanza_id in properties.stanza_ids:
-            if stanza_id.by == archive_jid:
+            if stanza_id.by == str(archive_jid):
                 return stanza_id
         return None
 
@@ -141,7 +148,7 @@ class MAM(BaseModule):
 
         if properties.type.is_groupchat:
             assert properties.jid is not None
-            archive_jid = properties.jid.bare
+            archive_jid = properties.jid.new_as_bare()
             timestamp = properties.timestamp
 
             disco_info = app.storage.cache.get_last_disco_info(archive_jid)
@@ -158,7 +165,7 @@ class MAM(BaseModule):
             if not self.available:
                 return
 
-            archive_jid = self._con.get_own_jid().bare
+            archive_jid = self._con.get_own_jid().new_as_bare()
             timestamp = None
 
         if not properties.stanza_ids:
@@ -211,14 +218,14 @@ class MAM(BaseModule):
             self._log.warning(stanza)
             raise nbxmpp.NodeProcessed
 
+        assert properties.remote_jid is not None
         stanza_id = properties.mam.id
-        if stanza_id is None:
-            self._log.warning('Unable to determine stanza id')
-            self._log.warning(stanza)
-            raise nbxmpp.NodeProcessed
 
         if app.storage.archive.check_if_stanza_id_exists(
-            self._account, properties.remote_jid, stanza_id):
+            self._account,
+            properties.remote_jid,
+            stanza_id
+        ):
             self._log.info('Received duplicated message from MAM: %s', stanza_id)
             raise nbxmpp.NodeProcessed
 
@@ -227,13 +234,13 @@ class MAM(BaseModule):
         valid_id = self._mam_query_ids.get(properties.mam.archive, None)
         return valid_id == properties.mam.query_id
 
-    def _get_query_id(self, jid: str) -> str:
+    def _get_query_id(self, jid: JID) -> str:
         query_id = generate_id()
         self._mam_query_ids[jid] = query_id
         return query_id
 
     def _get_query_params(self) -> tuple[str | None, datetime | None]:
-        own_jid = self._con.get_own_jid().bare
+        own_jid = self._con.get_own_jid().new_as_bare()
         archive = app.storage.archive.get_mam_archive_state(
             self._account, own_jid)
 
@@ -303,7 +310,7 @@ class MAM(BaseModule):
     def request_archive_on_signin(self) -> Generator[Any, Any]:
         _task = yield  # noqa: F841
 
-        own_jid = self._con.get_own_jid().bare
+        own_jid = self._con.get_own_jid().new_as_bare()
 
         if own_jid in self._mam_query_ids:
             self._log.warning('request already running for %s', own_jid)
@@ -422,7 +429,7 @@ class MAM(BaseModule):
                                        after=mam_id,
                                        start=start_date)
 
-        self._remove_query_id(result.jid)
+        self._remove_query_by_jid(result.jid)
 
         raise_if_error(result)
 
@@ -443,7 +450,7 @@ class MAM(BaseModule):
                                            after=result.rsm.last,
                                            start=start_date)
 
-            self._remove_query_id(result.jid)
+            self._remove_query_by_jid(result.jid)
 
             raise_if_error(result)
 
@@ -459,7 +466,7 @@ class MAM(BaseModule):
                                  queryid: str | None = None
                                  ) -> str:
 
-        jid = self._con.get_own_jid().bare
+        jid = self._con.get_own_jid().new_as_bare()
 
         if after is None:
             self._log.info('Request interval: %s, from %s to %s',
@@ -485,11 +492,11 @@ class MAM(BaseModule):
 
         try:
             result = task.finish()
-        except (StanzaError, MalformedStanzaError) as error:
-            self._remove_query_id(error.jid)
+        except (StanzaError, MalformedStanzaError):
+            self._remove_query_by_id(queryid)
             return
 
-        self._remove_query_id(result.jid)
+        self._remove_query_by_jid(result.jid)
 
         if start_date:
             timestamp = start_date
