@@ -19,13 +19,16 @@ from nbxmpp.const import InviteType
 from nbxmpp.const import StatusCode
 from nbxmpp.errors import StanzaError
 from nbxmpp.modules.dataforms import SimpleDataForm
+from nbxmpp.modules.muc.util import MucInfoResult
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 from nbxmpp.protocol import Message
 from nbxmpp.protocol import Presence
 from nbxmpp.structs import CommonError
+from nbxmpp.structs import CommonResult
 from nbxmpp.structs import DiscoInfo
 from nbxmpp.structs import MessageProperties
+from nbxmpp.structs import MucConfigResult
 from nbxmpp.structs import PresenceProperties
 from nbxmpp.structs import StanzaHandler
 from nbxmpp.structs import VoiceRequest
@@ -40,15 +43,17 @@ from gajim.common.const import MUCJoinedState
 from gajim.common.events import MucAdded
 from gajim.common.events import MucDecline
 from gajim.common.events import MucInvitation
-from gajim.common.helpers import get_default_muc_config
-from gajim.common.helpers import get_group_chat_nick
+from gajim.common.helpers import to_user_string
 from gajim.common.modules.base import BaseModule
 from gajim.common.modules.bits_of_binary import store_bob_data
+from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.structs import MUCData
 from gajim.common.structs import MUCPresenceData
 from gajim.common.util.datetime import utc_now
+from gajim.common.util.muc import get_default_muc_config
+from gajim.common.util.muc import get_group_chat_nick
 
 log = logging.getLogger('gajim.c.m.muc')
 
@@ -130,12 +135,12 @@ class MUC(BaseModule):
         self._con.connect_signal('resume-failed',
                                  self._on_client_resume_failed)
 
-        self._rejoin_muc: set[str] = set()
-        self._rejoin_timeouts: dict[str, int] = {}
+        self._rejoin_muc: set[JID] = set()
+        self._rejoin_timeouts: dict[JID, int] = {}
         self._muc_service_jid = None
         self._joined_users: defaultdict[
-            str, dict[str, MUCPresenceData]] = defaultdict(dict)
-        self._mucs: dict[str, MUCData] = {}
+            JID, dict[str, MUCPresenceData]] = defaultdict(dict)
+        self._mucs: dict[JID, MUCData] = {}
         self._muc_nicknames = {}
         self._voice_requests: dict[
             GroupchatContact, list[VoiceRequest]] = defaultdict(list)
@@ -159,7 +164,7 @@ class MUC(BaseModule):
         return self._muc_service_jid is not None
 
     @property
-    def service_jid(self):
+    def service_jid(self) -> JID | None:
         return self._muc_service_jid
 
     def pass_disco(self, info: DiscoInfo) -> None:
@@ -186,7 +191,7 @@ class MUC(BaseModule):
     def _get_mucs_with_state(self, states: list[MUCJoinedState]):
         return [muc for muc in self._mucs.values() if muc.state in states]
 
-    def _set_muc_state(self, room_jid: str, state: MUCJoinedState) -> None:
+    def _set_muc_state(self, room_jid: JID, state: MUCJoinedState) -> None:
         try:
             muc = self._mucs[room_jid]
         except KeyError:
@@ -208,13 +213,14 @@ class MUC(BaseModule):
             self._joined_users.pop(muc.jid, None)
             self._set_muc_state(muc.jid, MUCJoinedState.NOT_JOINED)
             room = self._get_contact(muc.jid)
+            assert isinstance(room, GroupchatContact)
             room.set_not_joined()
             room.notify('room-left')
 
         self._joined_users.clear()
 
     def _create_muc_data(self,
-                         room_jid: str,
+                         room_jid: JID,
                          nick: str | None,
                          password: str | None,
                          config: dict[str, Any] | None
@@ -228,7 +234,7 @@ class MUC(BaseModule):
             if bookmark.password is not None:
                 password = bookmark.password
 
-        return MUCData(room_jid, nick, None, password, config)
+        return MUCData(str(room_jid), nick, None, password, config)
 
     def join(self,
              jid: JID,
@@ -265,11 +271,11 @@ class MUC(BaseModule):
             self._set_muc_state(muc_data.jid, MUCJoinedState.JOINING)
             self._con.get_module('Discovery').disco_muc(
                 muc_data.jid,
-                callback=self._on_disco_result)
+                callback=self._on_disco_result)  # type: ignore
         else:
             self._join(muc_data)
 
-    def create(self, jid: str, config: dict[str, Any]) -> None:
+    def create(self, jid: JID, config: dict[str, Any]) -> None:
         if not app.account_is_available(self._account):
             return
 
@@ -280,12 +286,12 @@ class MUC(BaseModule):
         self._push_muc_added_event(jid, select_chat=True)
 
     def _push_muc_added_event(self,
-                              jid: str,
+                              jid: JID,
                               select_chat: bool = False
                               ) -> None:
 
         app.ged.raise_event(MucAdded(account=self._account,
-                                     jid=JID.from_string(jid),
+                                     jid=jid,
                                      select_chat=select_chat))
 
     def _on_disco_result(self, task: Task) -> None:
@@ -325,7 +331,7 @@ class MUC(BaseModule):
         self._set_muc_state(muc_data.jid, MUCJoinedState.JOINING)
         self._con.send_stanza(presence)
 
-    def _rejoin(self, room_jid: str) -> bool:
+    def _rejoin(self, room_jid: JID) -> bool:
         muc_data = self._mucs[room_jid]
         if muc_data.state.is_not_joined:
             self._log.info('Rejoin %s', room_jid)
@@ -346,7 +352,8 @@ class MUC(BaseModule):
 
     def leave(self,
               room_jid: JID,
-              reason: str | None = None
+              reason: str | None = None,
+              unregister: bool = False,
               ) -> None:
         self._log.info('Leave MUC: %s', room_jid)
 
@@ -370,9 +377,27 @@ class MUC(BaseModule):
 
         self._set_muc_state(room_jid, MUCJoinedState.NOT_JOINED)
         room = self._get_contact(room_jid)
+        assert isinstance(room, GroupchatContact)
         room.set_not_joined()
         room.notify('room-left')
 
+        if not unregister:
+            return
+
+        contact = self._con.get_module('Contacts').get_contact(room_jid)
+        assert isinstance(contact, GroupchatContact)
+        self._con.get_module('Register').unregister(
+            jid=contact.jid,
+            callback=self._unregister_callback,
+        )
+
+    def _unregister_callback(self, task: Task) -> None:
+        try:
+            task.finish()
+        except StanzaError as error:
+            self._log.error('Error while unregistering from MUC: %s',
+                            to_user_string(error))
+
     def abort_join(self, room_jid: JID) -> None:
         self._remove_rejoin_timeout(room_jid)
 
@@ -384,9 +409,9 @@ class MUC(BaseModule):
 
         self._set_muc_state(room_jid, MUCJoinedState.NOT_JOINED)
 
-    def configure_room(self, room_jid: str) -> None:
+    def configure_room(self, room_jid: JID) -> None:
         self._nbxmpp('MUC').request_config(room_jid,
-                                           callback=self._on_room_config)
+                                           callback=self._on_room_config)  # type: ignore
 
     def _on_room_config(self, task: Task) -> None:
         try:
@@ -399,6 +424,7 @@ class MUC(BaseModule):
             room.notfiy('room-config-failed', error_text)
             return
 
+        assert isinstance(result, MucConfigResult)
         self._log.info('Configure room: %s', result.jid)
 
         muc_data = self._mucs[result.jid]
@@ -433,8 +459,9 @@ class MUC(BaseModule):
             room.notfiy('room-config-failed', error_text)
             return
 
+        assert isinstance(result, CommonResult)
         self._con.get_module('Discovery').disco_muc(
-            result.jid, callback=self._on_disco_result_after_config)
+            result.jid, callback=self._on_disco_result_after_config)   # type: ignore
 
     def _on_disco_result_after_config(self, task: Task) -> None:
         try:
@@ -443,13 +470,15 @@ class MUC(BaseModule):
             self._log.info('Disco %s failed: %s', error.jid, error.get_text())
             return
 
+        assert isinstance(result, MucInfoResult)
         jid = result.info.jid
+        assert jid is not None
         muc_data = self._mucs[jid]
         self._room_join_complete(muc_data)
 
         self._log.info('Configuration finished: %s', jid)
 
-        room = self._get_contact(jid.bare)
+        room = self._get_contact(jid.new_as_bare())
         event = events.MUCRoomConfigFinished(
             timestamp=utc_now())
 
@@ -477,21 +506,17 @@ class MUC(BaseModule):
             status=message)
 
     def _on_error_presence(self,
-                           _con: types.xmppClient,
-                           stanza: Presence,
+                           _con: types.NBXMPPClient,
+                           _stanza: Presence,
                            properties: PresenceProperties
                            ) -> None:
 
-        room_jid = properties.jid.bare
+        assert properties.jid is not None
+        room_jid = properties.jid.new_as_bare()
         muc_data = self._mucs.get(room_jid)
         if muc_data is None:
             return
 
-        if properties.jid.resource != muc_data.nick:
-            self._log.warning('Unknown error presence')
-            self._log.warning(stanza)
-            return
-
         room = self._get_contact(room_jid)
 
         if muc_data.state == MUCJoinedState.JOINING:
@@ -544,24 +569,28 @@ class MUC(BaseModule):
             room.notify('room-presence-error', event)
 
     def _on_muc_user_presence(self,
-                              _con: types.xmppClient,
+                              _con: types.NBXMPPClient,
                               stanza: Presence,
                               properties: PresenceProperties
                               ) -> None:
 
-        room_jid = str(properties.muc_jid)
+        assert properties.type is not None
+        assert properties.muc_jid is not None
+        room_jid = properties.muc_jid
         if room_jid not in self._mucs:
             self._log.warning('Presence from unknown MUC')
             self._log.warning(stanza)
             return
 
         muc_data = self._mucs[room_jid]
+        assert properties.jid is not None
         occupant = self._get_contact(properties.jid, groupchat=True)
-        room = self._get_contact(properties.jid.bare)
+        room = self._get_contact(properties.jid.new_as_bare())
+        assert isinstance(room, GroupchatContact)
 
         timestamp = utc_now()
 
-        if properties.is_muc_destroyed:
+        if properties.muc_destroyed is not None:
             self._log.info('MUC destroyed: %s', room_jid)
             self._set_muc_state(room_jid, MUCJoinedState.NOT_JOINED)
             self._con.get_module('Bookmarks').remove(room_jid)
@@ -578,6 +607,7 @@ class MUC(BaseModule):
             return
 
         if properties.is_nickname_changed:
+            assert properties.muc_user is not None
             if properties.is_muc_self_presence:
                 muc_data.nick = properties.muc_user.nick
                 self._con.get_module('Bookmarks').modify(muc_data.jid,
@@ -643,6 +673,8 @@ class MUC(BaseModule):
             self._set_muc_state(room_jid, MUCJoinedState.NOT_JOINED)
             room.set_not_joined()
 
+            assert properties.muc_user is not None
+
             event = events.MUCRoomKicked(
                 timestamp=timestamp,
                 status_codes=properties.muc_status_codes,
@@ -662,14 +694,14 @@ class MUC(BaseModule):
             # unavailable presence, because we left the MUC
             return
 
+        if properties.jid.resource is None:
+            # prosody allows broadcasting "unavailable" presences from
+            # offline room members
+            return
+
         try:
             presence = self._process_user_presence(properties)
         except KeyError:
-            if (properties.type.is_unavailable
-                    and properties.muc_user.role.is_none):
-                # prosody allows broadcasting "unavailable" presences from
-                # offline room members
-                return
             # Sometimes it seems to happen that we get unavailable presence
             # from occupants we don’t know
             log.warning('Unexpected presence received')
@@ -703,6 +735,7 @@ class MUC(BaseModule):
             return
 
         if not presence.available:
+            assert properties.muc_user is not None
 
             event = events.MUCUserLeft(
                 timestamp=timestamp,
@@ -720,6 +753,7 @@ class MUC(BaseModule):
         signals_and_events: list[tuple[str, Any]] = []
 
         if occupant.affiliation != presence.affiliation:
+            assert properties.muc_user is not None
 
             event = events.MUCUserAffiliationChanged(
                 timestamp=timestamp,
@@ -733,6 +767,7 @@ class MUC(BaseModule):
             signals_and_events.append(('user-affiliation-changed', event))
 
         if occupant.role != presence.role:
+            assert properties.muc_user is not None
 
             event = events.MUCUserRoleChanged(
                 timestamp=timestamp,
@@ -759,12 +794,28 @@ class MUC(BaseModule):
             app.storage.events.store(occupant.room, event)
             signals_and_events.append(('user-status-show-changed', event))
 
+        if occupant.hats != presence.hats:
+            if presence.hats:
+                hats = [h.title for h in presence.hats.get_hats()]
+            else:
+                hats = None
+            event = events.MUCUserHatsChanged(
+                timestamp=timestamp,
+                is_self=properties.is_muc_self_presence,
+                nick=occupant.name,
+                hats=hats,
+            )
+
+            app.storage.events.store(occupant, event)
+            app.storage.events.store(occupant.room, event)
+            signals_and_events.append(('user-hats-changed', event))
+
         occupant.update_presence(presence)
         for signal, event in signals_and_events:
             occupant.notify(signal, event)
 
     def _on_muc_normal_user_message(self,
-                                    _con: types.xmppClient,
+                                    _con: types.NBXMPPClient,
                                     stanza: Presence,
                                     properties: MessageProperties) -> None:
         if not properties.muc_user or not properties.muc_user.jid:
@@ -773,20 +824,26 @@ class MUC(BaseModule):
         if not properties.muc_user.affiliation and not properties.muc_user.role:
             return
 
-        room_jid = str(properties.muc_jid)
+        room_jid = properties.muc_jid
         if room_jid not in self._mucs:
             self._log.warning('Message from unknown MUC')
             self._log.warning(stanza)
             return
 
+        assert room_jid is not None
         room = self._get_contact(room_jid)
+        assert isinstance(room, GroupchatContact)
 
         if properties.muc_user.nick is not None:
             nick = properties.muc_user.nick
         else:
             contact = self._get_contact(properties.muc_user.jid)
-            nick = contact.name
+            if isinstance(contact, BareContact):
+                nick = contact.name
+            else:
+                nick = str(properties.muc_user.jid)
 
+        assert properties.muc_user.affiliation is not None
         event = events.MUCAffiliationChanged(
             timestamp=utc_now(),
             nick=nick,
@@ -798,7 +855,7 @@ class MUC(BaseModule):
     def _process_user_presence(self,
                                properties: PresenceProperties
                                ) -> MUCPresenceData:
-
+        assert properties.jid is not None
         jid = properties.jid
         group_contact = self._client.get_module('Contacts').get_contact(
             jid.bare, groupchat=True)
@@ -807,30 +864,31 @@ class MUC(BaseModule):
             occupant_id = properties.occupant_id
 
         muc_presence = MUCPresenceData.from_presence(properties, occupant_id)
+        assert jid.resource is not None
         if not muc_presence.available:
-            self._joined_users[jid.bare].pop(jid.resource)
+            self._joined_users[jid.new_as_bare()].pop(jid.resource)
         else:
-            self._joined_users[jid.bare][jid.resource] = muc_presence
+            self._joined_users[jid.new_as_bare()][jid.resource] = muc_presence
         return muc_presence
 
     def _is_user_joined(self, jid: JID | None) -> bool:
         try:
-            self._joined_users[jid.bare][jid.resource]
+            self._joined_users[jid.new_as_bare()][jid.resource]
         except KeyError:
             return False
         return True
 
-    def get_joined_users(self, jid: str) -> list[str]:
+    def get_joined_users(self, jid: JID) -> list[str]:
         return list(self._joined_users[jid].keys())
 
-    def _start_rejoin_timeout(self, room_jid: str) -> None:
+    def _start_rejoin_timeout(self, room_jid: JID) -> None:
         self._remove_rejoin_timeout(room_jid)
         self._rejoin_muc.add(room_jid)
         self._log.info('Start rejoin timeout for: %s', room_jid)
         id_ = GLib.timeout_add_seconds(10, self._rejoin, room_jid)
         self._rejoin_timeouts[room_jid] = id_
 
-    def _remove_rejoin_timeout(self, room_jid: str) -> None:
+    def _remove_rejoin_timeout(self, room_jid: JID) -> None:
         self._rejoin_muc.discard(room_jid)
         id_ = self._rejoin_timeouts.get(room_jid)
         if id_ is not None:
@@ -839,7 +897,7 @@ class MUC(BaseModule):
             del self._rejoin_timeouts[room_jid]
 
     def _on_subject_change(self,
-                           _con: types.xmppClient,
+                           _con: types.NBXMPPClient,
                            _stanza: Message,
                            properties: MessageProperties
                            ) -> None:
@@ -847,7 +905,8 @@ class MUC(BaseModule):
         if not properties.is_muc_subject:
             return
 
-        room_jid = properties.jid.bare
+        assert properties.jid is not None
+        room_jid = properties.jid.new_as_bare()
 
         muc_data = self._mucs.get(room_jid)
         if muc_data is None:
@@ -906,14 +965,15 @@ class MUC(BaseModule):
                 muc_data.jid)
 
     def _on_voice_request(self,
-                          _con: types.xmppClient,
+                          _con: types.NBXMPPClient,
                           _stanza: Message,
                           properties: MessageProperties
                           ) -> None:
         if not properties.is_voice_request:
             return
 
-        room = self._get_contact(properties.jid.bare)
+        assert properties.jid is not None
+        room = self._get_contact(properties.jid.new_as_bare())
         assert isinstance(room, GroupchatContact)
         assert properties.voice_request is not None
 
@@ -944,7 +1004,7 @@ class MUC(BaseModule):
         self._voice_requests[contact].remove(voice_request)
 
     def _on_captcha_challenge(self,
-                              _con: types.xmppClient,
+                              _con: types.NBXMPPClient,
                               _stanza: Message,
                               properties: MessageProperties
                               ) -> None:
@@ -956,6 +1016,7 @@ class MUC(BaseModule):
             self._log.warning('Ignore captcha challenge received from MAM')
             raise nbxmpp.NodeProcessed
 
+        assert properties.jid is not None
         muc_data = self._mucs.get(properties.jid)
         if muc_data is None:
             return
@@ -975,7 +1036,7 @@ class MUC(BaseModule):
         self._set_muc_state(properties.jid, MUCJoinedState.CAPTCHA_REQUEST)
         self._remove_rejoin_timeout(properties.jid)
 
-        room = self._get_contact(properties.jid.bare)
+        room = self._get_contact(properties.jid.new_as_bare())
         room.notify('room-captcha-challenge')
 
         raise nbxmpp.NodeProcessed
@@ -999,7 +1060,7 @@ class MUC(BaseModule):
         self._set_muc_state(room_jid, MUCJoinedState.JOINING)
         self._nbxmpp('MUC').send_captcha(room_jid,
                                          form_node,
-                                         callback=self._on_captcha_result)
+                                         callback=self._on_captcha_result)  # type: ignore
 
     def _on_captcha_result(self, task: Task) -> None:
         try:
@@ -1014,7 +1075,7 @@ class MUC(BaseModule):
             room.notify('room-captcha-error', error_text)
 
     def _on_config_change(self,
-                          _con: types.xmppClient,
+                          _con: types.NBXMPPClient,
                           _stanza: Message,
                           properties: MessageProperties
                           ) -> None:
@@ -1040,11 +1101,19 @@ class MUC(BaseModule):
         raise nbxmpp.NodeProcessed
 
     def _on_invite_or_decline(self,
-                              _con: types.xmppClient,
+                              _con: types.NBXMPPClient,
                               _stanza: Message,
                               properties: MessageProperties
                               ) -> None:
 
+        assert properties.from_ is not None
+        if properties.from_.bare_match(self._get_own_bare_jid()):
+            # Invite/Decline sent by us and received via MAM or Carbons
+            # TODO: It could make sense to delete a pending invite
+            # if another device of ours decline the invite
+            self._log.warning('Ignored MUC Invite/Decline sent by other device')
+            return
+
         if properties.muc_decline is not None:
             data = properties.muc_decline
             contact = self._get_contact(data.muc, groupchat=True)
@@ -1060,6 +1129,7 @@ class MUC(BaseModule):
         if properties.muc_invite is not None:
             data = properties.muc_invite
             contact = self._get_contact(data.muc, groupchat=True)
+            assert isinstance(contact, GroupchatContact)
 
             self._log.info('Invite from: %s, to: %s', data.from_, data.muc)
 
@@ -1071,8 +1141,8 @@ class MUC(BaseModule):
             self._con.get_module('Discovery').disco_muc(
                 data.muc,
                 request_vcard=True,
-                callback=self._on_disco_result_after_invite,
-                user_data=data)
+                callback=self._on_disco_result_after_invite,  # type: ignore
+                user_data=data)  # type: ignore
 
             raise nbxmpp.NodeProcessed
 
@@ -1115,7 +1185,7 @@ class MUC(BaseModule):
         else:
             type_ = InviteType.DIRECT
 
-        password = self._mucs[str(room)].password
+        password = self._mucs[room].password
         self._log.info('Invite %s to %s', jid, room)
         return self._nbxmpp('MUC').invite(
             room, jid, password, reason, continue_, type_)
