@@ -22,6 +22,7 @@ from pathlib import Path
 import sqlalchemy as sa
 from nbxmpp import JID
 from sqlalchemy import delete
+from sqlalchemy import Row
 from sqlalchemy import select
 from sqlalchemy import union_all
 from sqlalchemy import update
@@ -52,6 +53,7 @@ from gajim.common.storage.base import AlchemyStorage
 from gajim.common.storage.base import timeit
 from gajim.common.storage.base import VALUE_MISSING
 from gajim.common.storage.base import with_session
+from gajim.common.storage.base import with_session_yield_from
 from gajim.common.util.datetime import FIRST_UTC_DATETIME
 from gajim.common.util.text import get_random_string
 
@@ -495,18 +497,20 @@ class MessageArchiveStorage(AlchemyStorage):
 
     @with_session
     @timeit
-    def get_conversation_jids(self, session: Session, account: str) -> Sequence[JID]:
+    def get_conversation_jids(
+        self, session: Session, account: str
+    ) -> Sequence[Row[tuple[JID, int]]]:
         fk_account_pk = self._get_account_pk(session, account)
 
         subq = (
-            select(Message.fk_remote_pk)
+            select(Message.fk_remote_pk, Message.type)
             .distinct()
             .where(Message.fk_account_pk == fk_account_pk)
         ).subquery()
 
-        stmt = select(Remote.jid).join(subq)
+        stmt = select(Remote.jid, subq.c.type).join(subq)
         self._explain(session, stmt)
-        return session.scalars(stmt).all()
+        return session.execute(stmt).fetchall()
 
     @with_session
     @timeit
@@ -741,8 +745,7 @@ class MessageArchiveStorage(AlchemyStorage):
         result = cast(Sequence[str] | None, session.scalars(stmt).all())
         return result
 
-
-    @with_session
+    @with_session_yield_from
     @timeit
     def search_archive(
         self,
@@ -1114,7 +1117,7 @@ class MessageArchiveStorage(AlchemyStorage):
 
             log.info('Removed messages older then %s', threshold.isoformat())
 
-    @with_session
+    @with_session_yield_from
     @timeit
     def get_messages_for_export(
         self, session: Session, account: str, jid: JID
@@ -1129,7 +1132,7 @@ class MessageArchiveStorage(AlchemyStorage):
                 Message.fk_remote_pk == fk_remote_pk,
                 Message.correction_id.is_(None),
             )
-            .order_by(sa.desc(Message.timestamp), sa.desc(Message.pk))
+            .order_by(Message.timestamp, Message.pk)
             .execution_options(yield_per=25)
         )
 
