@@ -402,8 +402,12 @@ class OMEMOStorage(Store):
 
     def remove_old_signed_pre_keys(self, timestamp: int) -> None:
         query = '''DELETE FROM signed_prekeys
-                   WHERE timestamp < datetime(?, "unixepoch")'''
-        self._con.execute(query, (timestamp,))
+                   WHERE prekey_id NOT IN (
+                    SELECT prekey_id FROM signed_prekeys
+                    ORDER BY timestamp desc LIMIT 3
+                   )'''
+
+        self._con.execute(query)
         self._con.commit()
 
     def load_session(self, recipient_id: str, device_id: int) -> SessionRecord:
