@@ -6,7 +6,6 @@ from __future__ import annotations
 
 import logging
 import sys
-from functools import partial
 from urllib.parse import urlparse
 
 from gi.repository import Gdk
@@ -356,7 +355,10 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
         if event.from_mam:
             return
 
-        if app.window.is_chat_active(event.account, event.jid):
+        if (
+            app.window.is_chat_active(event.account, event.jid)
+            and self._chat_control.view_is_at_bottom()
+        ):
             if event.message.id is None:
                 return
 
@@ -636,9 +638,8 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
                 contact.jid,
                 nick,
                 role,
-                callback=partial(
-                    self._on_affiliation_or_role_change, contact, jid, role
-                ),
+                callback=self._on_affiliation_or_role_change,
+                user_data=(contact, jid, role),
             )
 
         elif action_name == "muc-change-affiliation":
@@ -648,9 +649,8 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
             client.get_module("MUC").set_affiliation(
                 contact.jid,
                 {jid: {"affiliation": affiliation}},
-                callback=partial(
-                    self._on_affiliation_or_role_change, contact, jid, affiliation
-                ),
+                callback=self._on_affiliation_or_role_change,
+                user_data=(contact, jid, affiliation),
             )
 
         elif action_name == "muc-request-voice":
@@ -667,13 +667,9 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
                 self._last_quoted_id = row.pk
                 self._message_action_box.insert_as_quote(row.get_text(), clear=True)
 
-    def _on_affiliation_or_role_change(
-        self,
-        muc: GroupchatContact,
-        jid: JID | str,
-        affiliation_or_role: str,
-        task: Task,
-    ) -> None:
+    def _on_affiliation_or_role_change(self, task: Task) -> None:
+        muc, jid, affiliation_or_role = task.get_user_data()
+
         try:
             result = task.finish()
         except StanzaError as error:
@@ -872,10 +868,10 @@ class ChatPlaceholderBox(Gtk.Box):
         image.set_opacity(0.2)
         self.append(image)
 
-        button = Gtk.Button(label=_("Start Chatting…"))
-        button.set_halign(Gtk.Align.CENTER)
-        button.connect("clicked", self._on_start_chatting)
+        button = Gtk.Button(
+            label=_("Start Chatting…"),
+            halign=Gtk.Align.CENTER,
+            action_name="app.start-chat",
+            action_target=GLib.Variant("as", ["", ""]),
+        )
         self.append(button)
-
-    def _on_start_chatting(self, _button: Gtk.Button) -> None:
-        app.app.activate_action("start-chat", GLib.Variant("as", ["", ""]))
