@@ -7,7 +7,6 @@
 from __future__ import annotations
 
 import textwrap
-from collections.abc import Callable
 from collections.abc import Iterator
 from datetime import datetime
 from urllib.parse import quote
@@ -35,21 +34,20 @@ from gajim.common.util.muc import is_affiliation_change_allowed
 from gajim.common.util.muc import is_moderation_allowed
 from gajim.common.util.muc import is_role_change_allowed
 from gajim.common.util.text import escape_iri_path_segment
-from gajim.common.util.uri import filesystem_path_from_uri
 
 from gajim.gtk.const import MuteState
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import AddChatActionParams
 from gajim.gtk.structs import ChatListEntryParam
 from gajim.gtk.structs import DeleteMessageParam
+from gajim.gtk.structs import ExportHistoryParam
 from gajim.gtk.structs import ModerateAllMessagesParam
 from gajim.gtk.structs import ModerateMessageParam
 from gajim.gtk.structs import MuteContactParam
 
 MenuValueT = None | str | GLib.Variant | VariantMixin
 MenuItemListT = list[tuple[str, str, MenuValueT]]
-UriMenuItemsT = list[tuple[str, list[str], str]]
-UriMenuBuilderT = Callable[[URI, str], UriMenuItemsT]
+UriMenuItemsT = list[tuple[str, list[str] | VariantMixin, str]]
 
 
 class GajimMenu(Gio.Menu):
@@ -140,8 +138,10 @@ def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
     submenu = get_send_file_submenu()
     menu.append_submenu(_("Send File"), submenu)
 
-    params = AccountJidParam(account=account, jid=jid)
+    params = ExportHistoryParam(account=account, jid=jid)
     menu.add_item(_("Export History…"), "app.export-history", params)
+
+    params = AccountJidParam(account=account, jid=jid)
     menu.add_item(_("Remove History…"), "app.remove-history", params)
     return menu
 
@@ -150,6 +150,7 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
     account = contact.account
 
     params = AccountJidParam(account=account, jid=contact.jid)
+    export_params = ExportHistoryParam(account=account, jid=contact.jid)
 
     menu = GajimMenu()
 
@@ -162,7 +163,7 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
     # menu.add_item(_("Start Video Call…"), "win.start-video-call")
 
     if can_add_to_roster(contact):
-        menu.add_item(_("Add Contact…"), "win.add-to-roster", params)
+        menu.add_item(_("Add Contact…"), f"app.{account}-add-contact", params)
 
     if contact.is_in_roster:
         roster_add_params = GLib.Variant("as", [account, str(contact.jid)])
@@ -180,7 +181,7 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
         GLib.Variant("(sas)", (account, jids)),
     )
 
-    menu.add_item(_("Export History…"), "app.export-history", params)
+    menu.add_item(_("Export History…"), "app.export-history", export_params)
     menu.add_item(_("Remove History…"), "app.remove-history", params)
 
     return menu
@@ -193,12 +194,16 @@ def get_private_chat_menu(contact: types.GroupchatParticipant) -> GajimMenu:
 
     menu.add_item(_("Upload File…"), "win.send-file-httpupload", value)
 
-    params = AccountJidParam(account=contact.account, jid=contact.jid)
+    params = ExportHistoryParam(account=contact.account, jid=contact.jid)
     menu.add_item(_("Export History…"), "app.export-history", params)
+
+    params = AccountJidParam(account=contact.account, jid=contact.jid)
     menu.add_item(_("Remove History…"), "app.remove-history", params)
 
-    if can_add_to_roster(contact):
-        menu.add_item(_("Add to Contact List…"), "win.add-to-roster", params)
+    real_contact = contact.get_real_contact()
+    if real_contact is not None and can_add_to_roster(real_contact):
+        params = AccountJidParam(account=contact.account, jid=real_contact.jid)
+        menu.add_item(_("Add Contact…"), f"app.{contact.account}-add-contact", params)
 
     return menu
 
@@ -220,8 +225,10 @@ def get_groupchat_menu(contact: GroupchatContact) -> GajimMenu:
     menu.add_item(_("Request Voice"), "win.muc-request-voice", None)
     menu.add_item(_("Execute Command…"), "win.muc-execute-command", "")
 
-    params = AccountJidParam(account=contact.account, jid=contact.jid)
+    params = ExportHistoryParam(account=contact.account, jid=contact.jid)
     menu.add_item(_("Export History…"), "app.export-history", params)
+
+    params = AccountJidParam(account=contact.account, jid=contact.jid)
     menu.add_item(_("Remove History…"), "app.remove-history", params)
 
     return menu
@@ -382,122 +389,69 @@ def get_conv_action_context_menu(account: str, selected_text: str) -> Gio.Menu:
     return extra_menu
 
 
-def _xmpp_message_query_context_menu(uri: URI, account: str) -> UriMenuItemsT:
-    jid = uri.data["jid"]
-    # qparams = uri.query_params
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("copy-text", [jid], _("Copy XMPP Address")),
-        ("open-chat", [account, jid], _("Start Chat…")),
-        # ^ TODO: pass qparams ^
-        (f"{account}-add-contact", [account, jid], _("Add to Contact List…")),
-    ]
-
-
-def _xmpp_join_query_context_menu(uri: URI, account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("copy-text", [uri.data["jid"]], _("Copy XMPP Address")),
-        (
-            "open-chat",
-            [account, uri.data["jid"]],
-            # ^ TODO: pass qparams ^
-            _("Join Groupchat…"),
-        ),
-    ]
-
-
-_xmpp_uri_context_menus: dict[XmppUriQuery, UriMenuBuilderT] = {
-    XmppUriQuery.NONE: _xmpp_message_query_context_menu,
-    XmppUriQuery.MESSAGE: _xmpp_message_query_context_menu,
-    XmppUriQuery.JOIN: _xmpp_join_query_context_menu,
-}
-
-
 def _xmpp_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
-    return _xmpp_uri_context_menus[XmppUriQuery.from_str_or_none(uri.query_type)](
-        uri, account
-    )
-
-
-def _web_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("open-link", ["", uri.source], _("Open Link in Browser")),
+    menu_items: UriMenuItemsT = [
+        ("copy-text", [uri.data["jid"]], _("Copy XMPP Address")),
     ]
+    query_type = XmppUriQuery.from_str_or_none(uri.query_type)
+    if query_type in (XmppUriQuery.NONE, XmppUriQuery.MESSAGE):
+        params = AccountJidParam(account=account, jid=JID.from_string(uri.data["jid"]))
+        menu_items.extend(
+            [
+                ("open-chat", [account, uri.data["jid"]], _("Start Chat…")),
+                (f"{account}-add-contact", params, _("Add Contact…")),
+            ]
+        )
+        return menu_items
 
+    if query_type == XmppUriQuery.JOIN:
+        menu_items.append(
+            (
+                "open-chat",
+                [account, uri.data["jid"]],
+                _("Join Groupchat…"),
+            )
+        )
 
-def _mailto_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("copy-text", [uri.data["addr"]], _("Copy Email Address")),
-        ("open-link", ["", uri.source], _("Open Email Composer")),
-    ]
-
-
-def _geo_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("open-link", ["", uri.source], _("Show Location")),
-    ]
+    return menu_items
 
 
 def _ambiguous_addr_context_menu(uri: URI, account: str) -> UriMenuItemsT:
     addr = uri.data["addr"]
     mailto = "mailto:" + escape_iri_path_segment(addr)
-    return [
+
+    # addr could be a non valid jid
+    try:
+        params = AccountJidParam(account=account, jid=JID.from_string(addr))
+    except Exception:
+        params = None
+
+    items: UriMenuItemsT = [
         ("copy-text", [addr], _("Copy XMPP Address/Email")),
         ("open-link", ["", mailto], _("Open Email Composer")),
         ("open-chat", [account, addr], _("Start Chat…")),
-        (f"{account}-add-contact", [account, addr], _("Add to Contact List…")),
     ]
 
+    if params is not None:
+        items.append((f"{account}-add-contact", params, _("Add Contact…")))
 
-def _file_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
-    canopen = app.settings.get("allow_open_file_uris")
-    pathobj = filesystem_path_from_uri(uri.source)
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("open-link" if canopen else "-", ["", uri.source], _("Open Path")),
-        ("copy-text" if pathobj else "-", [str(pathobj)], _("Copy Path")),
-    ]
+    return items
 
 
-def _tel_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("open-link", [account, uri.source], _("Dial Number")),
-        # TODO:
-        # ('copy-text', [uri.data['number']], _('Copy Number')),
-    ]
-
-
-def _other_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
-    return [
-        ("copy-text", [uri.source], _("Copy Link Location")),
-        ("open-link", [account, uri.source], _("Open Link")),
-    ]
-
-
-_uri_context_menus: dict[URIType, UriMenuBuilderT] = {
-    URIType.XMPP: _xmpp_uri_context_menu,
-    URIType.MAIL: _mailto_uri_context_menu,
-    URIType.GEO: _geo_uri_context_menu,
-    URIType.WEB: _web_uri_context_menu,
-    URIType.FILE: _file_uri_context_menu,
-    URIType.AT: _ambiguous_addr_context_menu,
-    URIType.TEL: _tel_uri_context_menu,
-    URIType.OTHER: _other_uri_context_menu,
-}
-
-
-def get_uri_context_menu(account: str, uri: URI) -> Gio.Menu:
-    assert uri.type != URIType.INVALID  # it really begs to be a separate class
+def get_uri_context_menu(account: str, uri: URI) -> Gio.Menu | None:
+    if uri.type == URIType.XMPP:
+        menu_data = _xmpp_uri_context_menu(uri, account)
+    elif uri.type == URIType.AT:
+        menu_data = _ambiguous_addr_context_menu(uri, account)
+    else:
+        return None
 
     menuitems: MenuItemListT = []
 
-    for action, args, label in _uri_context_menus[uri.type](uri, account):
-        if len(args) == 1:
+    for action, args, label in menu_data:
+        if isinstance(args, VariantMixin):
+            value = args.to_variant()
+        elif len(args) == 1:
             value = GLib.Variant.new_string(args[0])
         else:
             value = GLib.Variant.new_strv(args)
@@ -506,10 +460,7 @@ def get_uri_context_menu(account: str, uri: URI) -> Gio.Menu:
             (label, f"app.{action}", value),
         )
 
-    menu = GajimMenu.from_list(menuitems)
-    extra_menu = Gio.Menu()
-    extra_menu.append_section(None, menu)
-    return extra_menu
+    return GajimMenu.from_list(menuitems)
 
 
 def get_account_notifications_menu(account: str) -> GajimMenu:
@@ -590,9 +541,16 @@ def get_chat_list_row_menu(
 
     submenu.add_item(_("New Workspace"), "win.move-chat-to-workspace", params)
 
-    if can_add_to_roster(contact):
-        params = AccountJidParam(account=account, jid=jid)
-        menu.add_item(_("Add to Contact List…"), "win.add-to-roster", params)
+    if isinstance(contact, GroupchatParticipant):
+        real_contact = contact.get_real_contact()
+    elif isinstance(contact, BareContact):
+        real_contact = contact
+    else:
+        real_contact = None
+
+    if real_contact is not None and can_add_to_roster(real_contact):
+        params = AccountJidParam(account=account, jid=real_contact.jid)
+        menu.add_item(_("Add Contact…"), f"app.{account}-add-contact", params)
 
     if app.window.get_chat_unread_count(account, jid, include_silent=True):
         params = AccountJidParam(account=account, jid=jid)
@@ -732,9 +690,9 @@ def get_groupchat_participant_menu(
 
     real_contact = contact.get_real_contact()
     if real_contact is not None and can_add_to_roster(real_contact):
-        value = GLib.Variant("as", [account, str(real_contact.jid)])
+        params = AccountJidParam(account=account, jid=real_contact.jid)
         action = f"app.{account}-add-contact"
-        general_items.insert(1, (_("Add to Contact List…"), action, value))
+        general_items.insert(1, (_("Add Contact…"), action, params.to_variant()))
 
     mod_menu = get_groupchat_mod_menu(self_contact, contact)
     admin_menu = get_groupchat_admin_menu(self_contact, contact)
@@ -982,6 +940,14 @@ def get_manage_roster_import_menu(accounts: list[tuple[str, str]]) -> GajimMenu:
     return menu
 
 
+def get_start_chat_menu():
+    menuitems: MenuItemListT = [
+        (_("Sort by Status"), "win.sort-by-show", None),
+    ]
+
+    return GajimMenu.from_list(menuitems)
+
+
 def escape_mnemonic(label: str | None) -> str | None:
     if label is None:
         return None
