@@ -1,8 +1,12 @@
+# This file is part of Gajim.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from __future__ import annotations
 
 import unittest
 from datetime import datetime
-from datetime import timezone
+from datetime import UTC
 
 from nbxmpp.protocol import JID
 from sqlalchemy.exc import IntegrityError
@@ -23,31 +27,30 @@ class ReceiptTest(unittest.TestCase):
         self._archive = MessageArchiveStorage(in_memory=True)
         self._archive.init()
 
-        self._account = 'testacc1'
-        self._account_jid = JID.from_string('user@domain.org')
-        self._remote_jid = JID.from_string('remote@jid.org')
+        self._account = "testacc1"
+        self._account_jid = JID.from_string("user@domain.org")
+        self._remote_jid = JID.from_string("remote@jid.org")
         self._init_settings()
 
     def _init_settings(self) -> None:
         app.settings = Settings(in_memory=True)
         app.settings.init()
-        app.settings.add_account('testacc1')
-        app.settings.set_account_setting(
-            'testacc1', 'address', 'user@domain.org')
+        app.settings.add_account("testacc1")
+        app.settings.set_account_setting("testacc1", "address", "user@domain.org")
 
     def test_receipt_join(self):
         receipt_data1 = Receipt(
             account_=self._account,
             remote_jid_=self._remote_jid,
-            id='messageid1',
-            timestamp=datetime.fromtimestamp(1, timezone.utc),
+            id="messageid1",
+            timestamp=datetime.fromtimestamp(1, UTC),
         )
 
         receipt_data2 = Receipt(
             account_=self._account,
             remote_jid_=self._remote_jid,
-            id='messageid1',
-            timestamp=datetime.fromtimestamp(3, timezone.utc),
+            id="messageid1",
+            timestamp=datetime.fromtimestamp(3, UTC),
         )
 
         self._archive.insert_object(receipt_data1)
@@ -60,11 +63,11 @@ class ReceiptTest(unittest.TestCase):
             remote_jid_=self._remote_jid,
             type=MessageType.CHAT,
             direction=ChatDirection.OUTGOING,
-            timestamp=datetime.now(timezone.utc),
+            timestamp=datetime.now(UTC),
             state=MessageState.ACKNOWLEDGED,
-            resource='res',
-            text='Some Message',
-            id='messageid1',
+            resource="res",
+            text="Some Message",
+            id="messageid1",
             stanza_id=get_uuid(),
             occupant_=None,
         )
@@ -78,10 +81,8 @@ class ReceiptTest(unittest.TestCase):
 
         self.assertIsNotNone(message.receipt)
 
-        self.assertEqual(
-            message.receipt.timestamp, datetime.fromtimestamp(1, timezone.utc)
-        )
+        self.assertEqual(message.receipt.timestamp, datetime.fromtimestamp(1, UTC))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
